import numpy as np
import matplotlib.pyplot as plt


#########   Import data  for plost

#Fig. 12, BICEPT+KECK/Planck  arXiv:1502.00612 The BICEP/Keck and Planck Collaborations, Phys. Rev. Lett. 114, 101301, 2015    https://lambda.gsfc.nasa.gov/graphics/bb_upperlimits/BB_data_2021apr_csv_format.dat
observedBKplanck = np.loadtxt("BK_Planck_new.txt")
thetaBKplanck = observedBKplanck[:,0]
deltaiswobservedBKplanck = observedBKplanck[:,1]
errorBKplanckmin = observedBKplanck[:,2]
errorBKplanckmax = observedBKplanck[:,3]
asymmetric_errorplanck = [errorBKplanckmin, errorBKplanckmax]


#Fig. 13 arXiv:1810.05216 http://bicepkeck.org/BK15_datarelease/BK15_bandpowers_20180920.txt
observedBK15150 = np.loadtxt("BK15_150.txt")
thetaBK15150 = observedBK15150[:,0]
deltaiswobservedBK15150 = observedBK15150[:,1]
errorBK15150 = observedBK15150[:,2]


bblt = np.loadtxt("clblt_new.txt")
l2 = bblt[:,0]
clbblt = bblt[:,1]

bbl = np.loadtxt("clbl_new.txt")
l3 = bbl[:,0]
clbbl = bbl[:,1]

bbt = np.loadtxt("clbt_new.txt")
l4 = bbt[:,0]
clbbt = bbt[:,1]

bbls6 = np.loadtxt("clbs68_new.txt")
l6 = bbls6[:,0]
clbbls6 = bbls6[:,1]

bbls7 = np.loadtxt("clbs72_new.txt")
l7 = bbls7[:,0]
clbbls7 = bbls7[:,1]

bbls8 = np.loadtxt("clbs75_new.txt")
l8 = bbls8[:,0]
clbbls8 = bbls8[:,1]


bblt5 = np.loadtxt("clbt5_new.txt")
lt9 = bblt5[:,0]
clbblt5 = bblt5[:,1]
##############################################


#  Overall Fig properties  #######################
plt.rc('text', usetex=True)   # for entire font
#plt.title('(a)', loc='left', fontsize=20, pad=13)
plt.xlabel(r'$\ell$', fontsize=18)
plt.ylabel(r'${\mathcal{D}^{\diamond}_{BB}} [\mu{\rm K}^2]$', fontsize=17)
plt.tick_params(direction='in',which='both',top=True, right=True,size=4)
plt.xticks(fontsize=16)
plt.yticks(fontsize=16)
plt.yscale('log')
plt.xscale('log')
plt.xlim([4,100])
plt.ylim([1e-06,1])
##############################

#### Plots #################
plt.plot(l2,clbblt,'k',linewidth=2,label='$\diamond\equiv$ (T+L)')

plt.plot(l2,clbbl,'k--',linewidth=2,label='$\diamond\equiv$ (L)')

plt.plot(l4,clbbt,'r-.',linewidth=1.5,label='$\diamond\equiv$ (T), $r=0.050$')
plt.plot(lt9,clbblt5,'r-.',linewidth=1,label='$\diamond\equiv$ (T), $r=0.005$')

plt.plot(l6,clbbls6,'b:',linewidth=1,label='$\diamond\equiv$ (S), $A_T=0.068$')

plt.plot(l7,clbbls7,'m--',linewidth=1,label='$\diamond\equiv$ (S), $A_T=0.072$')

plt.plot(l8,clbbls8,'g-',linewidth=1,label='$\diamond\equiv$ (S), $A_T=0.075$')

plt.errorbar(thetaBKplanck,deltaiswobservedBKplanck,yerr=asymmetric_errorplanck, fmt="o", color='tab:brown', label='BICEP2+Keck/Planck')
plt.errorbar(thetaBK15150,deltaiswobservedBK15150,yerr=errorBK15150, fmt="^b", label='BK150XBK150')
##########################

##########  Legend properties ############
plt.legend(loc='best',fontsize=8)
#######################################
########### Export Fig #########
plt.savefig('fig1_new.pdf')
plt.show() 
